The :mod:`pyspectral` API
=========================

Blackbody radiation
-------------------

.. automodule:: pyspectral.blackbody
    :members:
    :undoc-members:


Spectral responses
------------------

.. automodule:: pyspectral.rsr_reader
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: pyspectral.raw_reader
    :members:
    :undoc-members:
    :show-inheritance:
       

Solar irradiance
----------------

.. automodule:: pyspectral.solar
    :members:
    :undoc-members:
    :show-inheritance:


Near-Infrared reflectance
-------------------------

.. automodule:: pyspectral.near_infrared_reflectance
    :members:
    :undoc-members:
    :show-inheritance:

Rayleigh scattering
-------------------

   .. automodule:: pyspectral.rayleigh
       :members:
       :undoc-members:
       :show-inheritance:


Utils
-----

.. automodule:: pyspectral.utils
    :members:
    :undoc-members:
    :show-inheritance:
